# BCscannerBWA
 
BCscannerBWA software is a one-stop tool for barcode splitting. The software consists of 4 steps, including building reference database, comparing input data to reference database, filtering correction, and output data.



## Getting Started

### Prerequisites

Before you begin, ensure you have met the following requirements:
- Python 3.8 or higher
- A compatible operating system (e.g., Windows, macOS, Linux)

### Installation

To install the software, follow these steps:

```
pip install BCscannerBWA
```


## License 

This project is licensed under the MIT License.

## Contact
For any questions or feedback, please reach out to us at 605547565@qq.com.